/**
 * @Description 前端数据字典服务
 * @Author ZPFly
 * @Date 2021/10/12
 */
import dbService from "@/services/db.service";
import apiService from "@/services/api.service";
import sysDictInfoApi from "@/constants/api/ms-system/sys-dict.api";
import { RestfulResponse } from "@/model/domain/RestfulResponse";
import { Code } from "@/constants/enum/general/code.enum";
class DictService {
  // table = dbService.store.sysDict.name;
  /**
   * @Description TODO 数据字典内容，临时存放在系统，后续需要全部入库
   * @Author zhangmk
   * @Date 2021年12月31日17:58:48
   */
  private dictData = ([
    { s_field_name: '是否撤销', s_field: 'ISREVOCATION', value: '1', text: '是' },
    { s_field_name: '是否撤销', s_field: 'ISREVOCATION', value: '0', text: '否' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '100', text: '内资企业' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '150', text: '有限责任公司' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '151', text: '有限责任公司-国有独资公司' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '159', text: '有限责任公司-其他有限责任公司' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '160', text: '股份有限公司' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '110', text: '国有全资' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '120', text: '集体全资' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '190', text: '其他内资' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '130', text: '股份合作' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '140', text: '联营' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '170', text: '私有' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '172', text: '私有合伙' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '171', text: '私有独资' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '179', text: '其他私有' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '300', text: '外商投资企业' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '310', text: '外商投资企业-中外合资经营企业' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '320', text: '外商投资企业-中外合作经营企业' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '330', text: '外商投资企业-外资企业' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '390', text: '其他外商投资企业' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '340', text: '外商投资企业－外商投资股份有限公司' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '200', text: '港、澳、台投资企业' },
    {
      s_field_name: '经济类型分类',
      s_field: 'ECOTYPE',
      value: '210',
      text: '港澳台商投资企业-合资经营企业(港或澳、台资)'
    },
    {
      s_field_name: '经济类型分类',
      s_field: 'ECOTYPE',
      value: '220',
      text: '港澳台商投资企业-合作经营企业(港或澳、台资)'
    },
    {
      s_field_name: '经济类型分类',
      s_field: 'ECOTYPE',
      value: '230',
      text: '港澳台商投资企业-港、澳、台商独资经营企业'
    },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '290', text: '其他港澳台投资企业' },
    {
      s_field_name: '经济类型分类',
      s_field: 'ECOTYPE',
      value: '240',
      text: '港澳台商投资企业-港、澳、台商投资股份有限公司'
    },
    {
      s_field_name: '经济类型分类',
      s_field: 'ECOTYPE',
      value: '220',
      text: '港澳台商投资企业-合资经营企业(港或澳、台资)'
    },
    {
      s_field_name: '经济类型分类',
      s_field: 'ECOTYPE',
      value: '230',
      text: '港澳台商投资企业-合资经营企业(港或澳、台资)'
    },
    {
      s_field_name: '经济类型分类',
      s_field: 'ECOTYPE',
      value: '290',
      text: '港澳台商投资企业-合资经营企业(港或澳、台资)'
    },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '400', text: '境外机构' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '900', text: '其它' },
    { s_field_name: '经济类型分类', s_field: 'ECOTYPE', value: '175', text: '个体经营' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '010', text: '企业法人' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '012', text: '集体' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '013', text: '股份合作' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '014', text: '联营' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '015', text: '有限责任公司' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '016', text: '股份有限公司' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '017', text: '私营' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '019', text: '外资企业' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '020', text: '非法人企业' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '030', text: '国家机关' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '040', text: '实行预算管理的事业单位' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '050', text: '非预算管理的事业单位' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '070', text: '社会团体' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '120', text: '有字号的个体工商户' },
    { s_field_name: '企业类型', s_field: 'ENTTYPE', value: '999', text: '其他组织' },
    { s_field_name: '经营状态代码', s_field: 'ENTSTATUS', value: '11', text: '开业-正常经营' },
    { s_field_name: '经营状态代码', s_field: 'ENTSTATUS', value: '30', text: '吊销' },
    { s_field_name: '经营状态代码', s_field: 'ENTSTATUS', value: '20', text: '注销' },
    { s_field_name: '经营状态代码', s_field: 'ENTSTATUS', value: '90', text: '其他' },
    { s_field_name: '经营状态代码', s_field: 'ENTSTATUS', value: '12', text: '开业-经营困难' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'RS', text: '市人社局：' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'RS01', text: '市人社局：企业提警示信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'GT', text: '市国土局：' },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'GT01',
      text: '市国土局：未按《出让合同》交款的时限内按时缴纳土地价款'
    },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'GT02',
      text: '市国土局：未经国土、规划等相关部门批准非法用地'
    },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'GT03',
      text: '市国土局：未在成交确认书的约定时限内签订《出让合同》'
    },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'GT04',
      text: '市国土局：经多次催促未签订《出让合同》'
    },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'GT05',
      text: '市国土局：经多次催缴后拒绝缴纳土地价款'
    },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'GT06',
      text: '市国土局：经相关执法部门查处后拒绝整改'
    },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'HB', text: '市环保局：' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'HB01', text: '市环保局：未按规定交纳排污费' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'HB02', text: '市环保局：其他提警示信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'FG', text: '市房管局：' },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'FG01',
      text: '市房管局：因违反规范性文件、行业规范，受到房产行政主管部门、行业协会通报批评的'
    },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'FG99', text: '市房管局：其他提警示信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'WS', text: '市卫计委：' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'WS01', text: '市卫计委：企业已进入吊销程序的' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'AJ', text: '市安监局：' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'AJ01', text: '市安监局：发生职业病防治责任事故' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'AJ99', text: '市安监局：安监局其他提警示信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'XR', text: '市兴蓉集团：' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'XR01', text: '市兴蓉集团：其他不良信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'DY', text: '成都电业局：' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'DY01', text: '成都电业局：其他提警示信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'JX', text: '市经信委：' },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'JX01',
      text: '市经信委：未进行无线电台(站)执照年检信息'
    },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'GJ', text: '成都公积金中心：' },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'GJ01',
      text: '单位收到催建通知书后仍未按规定建立住房公积金制度'
    },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'HG', text: '成都海关：' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'HG01', text: '成都海关：海关进出口黑名单信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'HG99', text: '成都海关：海关主体提警示信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'XN', text: '市政务办：' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'XN01', text: '市政务办：法人不良信用信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'XN02', text: '市政务办：投资人不良信用信息' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'NW', text: '市农委：' },
    {
      s_field_name: '提警示信息',
      s_field: 'CONDITION',
      value: 'NW01',
      text: '市农委：未通过农业产业化经营重点龙头企业经济运行情况监测'
    },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'NW02', text: '市农委：被依法认定拖漏欠税款' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'NW03', text: '市农委：产品出现质量安全问题' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'NW04', text: '市农委：坑农害农' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'NW05', text: '市农委：企业及法人涉嫌犯罪' },
    { s_field_name: '提警示信息', s_field: 'CONDITION', value: 'NW99', text: '市农委：其他不良信息' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'FZ', text: '市发改委' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'FZ001', text: '市发改委：价格行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'JX', text: '市经信委' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JX001',
      text: '市经信委：非法设置无线电台(站)信息'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'WS', text: '市卫计委' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'WS001', text: '市卫计委：公共场所卫生行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'WS002', text: '市卫计委：供水单位卫生行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'WS003', text: '市卫计委：放射诊疗卫生行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'WS004', text: '市卫计委：医疗卫生行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG', text: '市城管委' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG001', text: '市城管委：市容秩序' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG002', text: '市城管委：环境卫生' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG003', text: '市城管委：广告招牌' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG004', text: '市城管委：市政设施' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG005', text: '市城管委：园林绿化' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG006', text: '市城管委：环境污染' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG007', text: '市城管委：扬尘治理' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CG008', text: '市城管委：其他' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'JS', text: '市建委' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS001',
      text:
        '市建委：因违反《安全生产许可证条例》、《建设工程安全生产管理条例》、《建筑施工企业安全生产许可证管理规定》、《建筑起重机械安全监督管理规定》、《成都市房屋建筑和市政基础设施工程施工安全监督管理规定》、《建筑施工企业主要负责人、项目负责人和专职安全生产管理人员安全生产管理规定》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS002',
      text:
        '市建委：因违反《城市房地产开发经营管理条例》、《房地产开发企业资质管理规定》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS003',
      text:
        '市建委：因违反《中华人民共和国建筑法》、《建设工程质量管理条例》、《房屋建筑和市政基础设施工程竣工验收备案管理办法》、《建筑工程施工许可管理办法》、《房屋建筑和市政基础设施工程施工图设计文件审查管理办法》、《实施工程建设强制性标准监督规定》、《建设工程质量检测管理办法》、《四川省建筑管理条例》、《四川省建设工程质量管理规定》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS004',
      text:
        '市建委：因违反《房屋建筑工程抗震设防管理规定》、《市政公用设施抗灾设防管理规定》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS005',
      text:
        '市建委：因违反《中华人民共和国节约能源法》、《民用建筑节能条例》、《民用建筑节能管理规定》、《四川省民用建筑节能管理办法》、《成都市建筑节能管理规定》、《成都市禁止生产和使用实心粘土砖管理暂行办法》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS006',
      text:
        '市建委：因违反《城市地下管线工程档案管理办法》、《四川省建筑装饰装修管理办法》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS007',
      text: '市建委：因违反《房屋建筑工程质量保修办法》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS008',
      text:
        '市建委：因违反《中华人民共和国招标投标法》、《招标投标法实施条例》、《建筑工程设计招标投标管理办法》、《房屋建筑和市政基础设施工程施工招标投标管理办法》、《工程建设项目施工招标投标办法》、《评标委员会和评标办法暂行规定》、《房屋建筑和市政基础设施工程施工分包管理办法》、《四川省国家投资工程建设项目招标投标条例》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS009',
      text:
        '市建委：因违反《建设工程勘察设计管理条例》、《建设工程勘察质量管理办法》、《建筑业企业资质管理规定》、《建设工程勘察设计资质管理规定》、《勘查设计注册工程师管理规定》、《四川省建设工程勘查设计管理条例》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS010',
      text:
        '市建委：因违反《工程监理企业资质管理规定》、《注册监理工程师管理规定》、《四川省建设工程监理规定》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS011',
      text:
        '市建委：因违反《工程造价咨询企业管理办法》、《工程建设项目招标代理机构资格认定办法》、《注册造价师管理办法》、《四川省工程建设项目招标代理办法》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS012',
      text:
        '市建委：因违反《中华人民共和国注册建筑师条例》、《注册建筑师条例实施细则》、《注册建造师管理规定》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS013',
      text:
        '市建委：因违反《散装水泥管理办法》、《四川省散装水泥管理办法》、《成都市散装水泥管理办法》，受到建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JS014',
      text:
        '市建委：因违反《成都市城市扬尘污染防治管理暂行规定》、《成都市建筑施工现场监督管理规定》、《成都市建设领域防范拖欠农民工工资管理办法》，受到建设行政主管部门行政处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'JT', text: '市交委' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JT001',
      text: '市交委：对道路旅客运输违规行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JT002',
      text: '市交委：对道路货物运输违规行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JT003',
      text: '市交委：对道路危险货物运输违规行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JT004',
      text: '市交委：对机动车驾驶员培训违规行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JT005',
      text: '市交委：对出租汽车经营违规行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JT006',
      text: '市交委：对违反《公路法》行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JT007',
      text: '市交委：对违反《四川省水上交通安全管理条例》行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JT008',
      text: '市交委：其他违反交通运输法规行为的处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'NW', text: '市农委' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW001',
      text: '市农委：违反《中华人民共和国种子法》'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW002',
      text: '市农委：违反《中华人民共和国农药管理条例》'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW003',
      text: '市农委：违反《中华人民共和国肥料管理办法》'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'NW004', text: '市农委：违反《兽药管理条例》' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW005',
      text: '市农委：违反《饲料和饲料添加剂管理条例》'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW006',
      text: '市农委：违反《中华人民共和国畜牧法》'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW007',
      text: '市农委：违反《农业转基因生物安全管理条例》'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW008',
      text: '市农委：违反《中华人民共和国动物防疫法》'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'NW009', text: '市农委：违反《植物检疫条例》' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW010',
      text: '市农委：违反《中华人民共和国农产品质量安全法》'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'NW011',
      text: '市农委：违反《中华人民共和国农村土地承包法》'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'TY', text: '市体育局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TY001',
      text: '市体育局：取得经营高危险性体育项目许可证后，不再符合规定条件仍经营该项目的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TY002',
      text:
        '市体育局：高危险性体育项目的经营者未按照规定做好体育设施、设备、器材的维护保养及定期检测，不能保证安全、正常使用的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TY003',
      text: '市体育局：高危险性体育项目的经营者对体育执法人员依法履行监督检查职责不予配合，拒绝阻挠执法的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TY004',
      text:
        '市体育局：高危险性体育项目的经营者未将该项体育项目可能危及消费者安全的事项和对参与者年龄、身体、技术的特殊要求等做出真实说明和明确警示的；或对危险未采取措施防止危害发生的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TY005',
      text: '市体育局：违反规定出租公共文化体育设施的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TY006',
      text: '市体育局：开展与公共文化体育设施功能、用途不相适应的服务活动的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SF', text: '市司法局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SF001',
      text: '市司法局：因违反《律师法》受到司法行政机关的行政处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SF002',
      text: '市司法局：因违反《公证法》、《公证机构执业管理办法》受到司法行政机关行政处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SF003',
      text: '市司法局：因违反《司法鉴定机构登记管理办法》受到司法行政机关的行政处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GA', text: '市公安局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA001',
      text: '市公安局：因违反《大型群众性活动安全管理条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA002',
      text: '市公安局：因违反《中华人民共和国枪支管理法》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA003',
      text: '市公安局：因违反《民用爆炸物品安全管理条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA004',
      text: '市公安局：因违反《爆破作业单位许可证》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA005',
      text: '市公安局：因违反《易制毒化学品管理条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA006',
      text: '市公安局：因违反《中华人民共和国校车安全条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA007',
      text: '市公安局：因违反《中华人民共和国道路交通安全法》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA008',
      text: '市公安局：因违反《危险化学品安全管理条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA009',
      text: '市公安局：因违反《中华人民共和国集会游行示威法》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA010',
      text: '市公安局：因违反《金融机构营业场所和金库安全防范设施建设许可实施办法》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA011',
      text: '市公安局：因违反《中华人民共和国消防法》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA012',
      text: '市公安局：因违反《中华人民共和国户口登记条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA013',
      text: '市公安局：因违反《成都市建筑垃圾处置管理条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA014',
      text: '市公安局：因违反《四川省消防条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA015',
      text: '市公安局：因违反《成都市消防条例》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA016',
      text: '市公安局：因违反《建设工程消防监督管理规定》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA017',
      text: '市公安局：因违反《消防监督检查规定》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA018',
      text: '市公安局：因违反《火灾事故调查规定》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA019',
      text: '市公安局：因违反《消防产品监督管理规定》，受到公安行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GA020',
      text: '市公安局：因违反《社会消防技术服务管理规定》，受到公安行政管理部门行政处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'AJ', text: '市安监局' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'AJ001', text: '市安监局：警告处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'AJ002', text: '市安监局：罚款处罚' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'AJ003',
      text: '市安监局：责令停产停业整顿、责令停产停业、责令停止建设、责令停止施工处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'AJ004',
      text: '市安监局：没收违法所得和非法财物处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'AJ005', text: '市安监局：暂扣或吊销有关许可证' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'AJ006', text: '市安监局：其他行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'TJ', text: '市统计局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ001',
      text:
        '市统计局：对有关单位负责人自行修改统计资料、编造虚假统计数据，要求统计机构、统计人员或者其他机构、人员伪造、篡改统计资料，对依法履行职责或者拒绝、抵制统计违法行为的统计人员打击报复，对本地方、本部门、本单位发生的严重统计违法行为失察的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ002',
      text:
        '市统计局：对县级以上人民政府统计机构或者有关部门在组织实施统计调查活动中未经批准擅自组织实施统计调查，擅自变更统计调查制度的内容，伪造、篡改统计资料，要求统计调查对象或者其他机构、人员提供不真实的统计资料，未按照统计调查制度的规定报送有关资料的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ003',
      text:
        '市统计局：对统计人员伪造、篡改统计资料，要求统计调查对象或其他机构、人员提供不真实的统计资料，未按照统计调查制度的规定报送有关资料的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ004',
      text:
        '市统计局：对国家机关及相关人员拒绝提供统计资料或者经催报后仍未按时提供统计资料，提供不真实或者不完整的统计资料，拒绝答复或者不如实答复统计检查查询书，拒绝、阻碍统计调查、统计检查，转移、隐匿、篡改、毁弃或者拒绝提供原始记录和凭证、统计台账、统计调查表及其他相关证明和资料的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ005',
      text:
        '市统计局：对企业事业单位或者其他组织及相关人员拒绝提供统计资料或者经催报后仍未按时提供统计资料，提供不真实或者不完整的统计资料，拒绝答复或者不如实答复统计检查查询书，拒绝、阻碍统计调查、统计检查，转移、隐匿、篡改、毁弃或者拒绝提供原始记录和凭证、统计台账、统计调查表及其他相关证明和资料的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ006',
      text:
        '市统计局：对个体工商户拒绝提供统计资料或者经催报后仍未按时提供统计资料，提供不真实或者不完整的统计资料，拒绝答复或者不如实答复统计检查查询书，拒绝、阻碍统计调查、统计检查，转移、隐匿、篡改、毁弃或者拒绝提供原始记录和凭证、统计台账、统计调查表及其他相关证明和资料的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ007',
      text:
        '"市统计局：对国家机关、企业事业单位、个体工商户或者其他组织及相关人员迟报统计资料,不按规定建立原始记录、统计台账,未按规定领取统计报表的处罚"'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ008',
      text: '市统计局：对个人在重大国情国力普查活动中拒绝、阻碍统计调查，提供不真实或者不完整的普查资料的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ009',
      text: '市统计局：对政府有关部门及有关人员未按规定提供行政登记资料的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'TJ010',
      text: '市统计局：对国家机关以外的组织或者个人擅自进行依法应当由国家机关实施的统计调查的处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'FG', text: '市房管局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG001',
      text:
        '市房管局：因违反《城市房地产管理法》、《城市房地产开发经营管理条例》、《商品房销售管理办法》、《城市商品房预售管理办法》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG002',
      text: '市房管局：因违反《房地产经纪管理办法》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG003',
      text: '市房管局：因违反《商品房屋租赁管理办法》、《成都市房屋租赁管理办法》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG004',
      text:
        '市房管局：因违反《物业管理条例》、《物业服务企业资质管理办法》、《四川省物业管理条例》、《成都市物业管理条例》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG005',
      text: '市房管局：因违反《房产测绘管理办法》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG006',
      text: '市房管局：因违反《房地产估价机构管理办法》、《注册房地产估价师管理办法》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG007',
      text:
        '市房管局：因违反《住宅专项维修资金管理办法》、《成都市城市住房专项维修资金管理暂行办法》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG008',
      text:
        '市房管局：因违反《住宅室内装饰装修管理办法》、《成都市房屋使用安全管理条例》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG009',
      text: '市房管局：因违反《城市房屋白蚁防治管理规定》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG010',
      text: '市房管局：因违反《成都市城市扬尘污染防治管理暂行规定》，受到房产行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'FG011',
      text: '市房管局：因违反《公共租赁住房管理办法》，受到房产行政主管部门行政处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW', text: '市国税局、市地税局' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW001', text: '市国税局、市地税局：偷税' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SW002',
      text: '市国税局、市地税局：逃避追缴欠税'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW003', text: '市国税局、市地税局：骗税' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW004', text: '市国税局、市地税局：抗税' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW005', text: '市国税局、市地税局：非法避税' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW006', text: '市国税局、市地税局：欠税' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW007', text: '市国税局、市地税局：发票违法' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SW008',
      text: '市国税局、市地税局：违反税务管理规定'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW011', text: '市国税局、市地税局：非违法违章' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SW090', text: '市国税局、市地税局：其他' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'ZJ', text: '市质监局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ001',
      text: '市质监局：因违反《产品质量法》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ002',
      text: '市质监局：因违反《计量法》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ003',
      text: '市质监局：因违反《标准化法》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ004',
      text: '市质监局：因违反《特种设备安全法》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ005',
      text: '市质监局：因违反《工业产品生产许可证管理条例》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ006',
      text: '市质监局：因违反《认证认可条例》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ007',
      text: '市质监局：因违反《四川省产品质量监督管理条例》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ008',
      text: '市质监局：因违反《四川省组织机构代码管理办法》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ009',
      text: '市质监局：因违反《四川省商品条码管理办法》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ010',
      text: '市质监局：因违反《成都市产品质量监督条例》，受到质量技术监督行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'ZJ011',
      text: '市质监局：因违反《成都市电梯安全监督管理办法》，受到质量技术监督行政主管部门行政处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'YJ', text: '市食药监局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'YJ001',
      text: '市食药监局：食品(含保健食品)行政处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'YJ002', text: '市食药监局：药品行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'YJ003', text: '市食药监局：医疗器械行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'YJ004', text: '市食药监局：化妆品行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GH', text: '市规划局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH001',
      text: '市规划局：因违反《中华人民共和国城乡规划法》，受到规划行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH002',
      text: '市规划局：因违反《四川省城乡规划条例》，受到规划行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH003',
      text: '市规划局：因违反《成都市城乡规划条例》，受到规划行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH004',
      text: '市规划局：因违反《中华人民共和国测绘法》，受到测绘地理信息行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH005',
      text: '市规划局：因违反《中华人民共和国测量标志保护条例》，受到测绘地理信息行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH006',
      text: '市规划局：因违反《中华人民共和国测绘成果管理条例》，受到测绘地理信息行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH007',
      text: '市规划局：因违反《地图管理条例》，受到测绘地理信息行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH008',
      text: '市规划局：因违反《基础测绘条例》，受到测绘地理信息行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH009',
      text: '市规划局：因违反《四川省测绘管理条例》，受到测绘地理信息行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GH099',
      text: '市规划局：因违反其他法律法规，受到规划行政主管部门、测绘地理信息行政主管部门行政处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'JY', text: '成都检验检疫局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JY001',
      text: '成都检验检疫局：对违反检验检疫法律法规违法行为的行政处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'HB', text: '市环保局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'HB001',
      text: '市环保局：违反环境保护法律法规的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'HB002',
      text: '市环保局：违反环境信息公开制度的处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GS', text: '市工商局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GS001',
      text: '市工商局：对违反登记管理有关法规行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GS002',
      text: '市工商局：对不正当竞争行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GS003',
      text: '市工商局：对侵害消费者权益行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GS004',
      text: '市工商局：对产品质量违法行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GS005',
      text: '市工商局：对合同行政违法行为的处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GS006', text: '市工商局：对商标违法行为的处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GS007', text: '市工商局：对广告违法行为的处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GS008', text: '市工商局：对直销违规行为的处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GS009', text: '市工商局：对传销行为的处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GS010', text: '市工商局：对限制竞争行为的处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'GS011', text: '市工商局：对垄断行为的处罚' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'GS099',
      text: '市工商局：对其他市场违法行为的处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'MZ', text: '市民政局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'MZ001',
      text: '市民政局：对违反登记管理行为的处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'JU', text: '市教育局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JU001',
      text: '市教育局：违反法律、法规和国家有关规定举办学校或其他教育机构的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JU002',
      text: '市教育局：学校和其他教育机构违法颁发学位、学历或者其他学业证书行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JU003',
      text: '市教育局：民办学校管理混乱严重影响教育教学的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JU004',
      text: '市教育局：民办学校出资人违法违规获取回报的处罚(出资人为法人)'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JU005',
      text: '市教育局：中等职业技术学校经检查评估不符合要求的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JU006',
      text: '市教育局：学校及其他教育机构禁止吸烟场所未按规定设置禁烟标识或违反规定设置吸烟器具的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'JU007',
      text: '市教育局：学校违反国家有关规定招收学生的处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'WG', text: '市文广新局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'WG001',
      text: '市文广新局：因违反《电影管理条例》，受到电影行政管理部门的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'WG002',
      text: '市文广新局：因违反《营业性演出管理条例》，受到文化行政管理部门的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'WG003',
      text: '市文广新局：因违反《营业性演出管理条例实施细则》，受到文化行政管理部门的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'WG004',
      text: '市文广新局：因违反《四川省文化市场管理条例》，受到文化行政管理部门的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'WG005',
      text: '市文广新局：因违反《印刷业管理条例》，受到出版行政管理部门的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'WG006',
      text: '市文广新局：因违反《出版管理条例》，受到出版行政管理部门的处罚'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'LY', text: '市林业园林局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LY001',
      text:
        '市林业园林局：因违反《中华人民共和国森林法》、《中华人民共和国森林法实施条例》，受到林业主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LY002',
      text:
        '市林业园林局：因违反《中华人民共和国野生动物保护法》、《中华人民共和国陆生野生动物保护实施条例》、《四川省〈中华人民共和国野生动物保护法〉实施办法》，受到林业行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LY003',
      text: '市林业园林局：因违反《中华人民共和国种子法》、《四川省林木种子管理条例》，受到林业行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LY004',
      text: '市林业园林局：因违反《四川省木材运输管理条例》，受到林业行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LY005',
      text:
        '市林业园林局：因违反《四川省自然保护区管理条例》、《四川省天然林保护条例》、《四川省森林公园管理条例》，受到林业行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LY006',
      text: '市林业园林局：因违反《四川省绿化条例》、《成都市古树名木保护管理规定》，受到林业行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LY007',
      text:
        '市林业园林局：因违反《森林病虫害防治条例》、《植物检疫条例》、《四川省植物检疫条例》，受到林业行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LY008',
      text: '市林业园林局：因违反《森林防火条例》，受到林业行政主管部门行政处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'LU', text: '市旅游局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LU001',
      text: '市旅游局：因违反《中华人民共和国旅游法》，受到旅游行政管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LU002',
      text: '市旅游局：因违反《旅行社条例》，受到旅游行政管理部门处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LU003',
      text: '市旅游局：因违反《中国公民出国旅游管理办法》，受到旅游行政管理部门处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LU004',
      text: '市旅游局：因违反《四川省旅游条例》，受到旅游行政管理部门处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LU005',
      text: '市旅游局：因违反《成都市旅游业促进条例》，受到旅游行政管理部门处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LU006',
      text: '市旅游局：因违反《旅行社条例实施细则》，受到旅游行政管理部门处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'LU007',
      text: '市旅游局：因违反《导游人员管理条例》，受到旅游行政管理部门处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'DC', text: '成调队' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'DC001', text: '成调队：统计违法行为处罚信息' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'YC', text: '市烟草专卖局' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'YC001', text: '市烟草专卖局：行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SH', text: '市水务局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH001',
      text: '市水务局：因违反《四川省城市供水条例》，受到城市供水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH002',
      text: '市水务局：因违反《城市供水条例》，受到城市供水行政主管部门或者其授权的单位行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH003',
      text: '市水务局：因违反《成都市城市供水管理条例》，受到城市供水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH004',
      text: '市水务局：因违反《城市供水水质管理规定》，受到直辖市、市、县人民政府城市供水主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH005',
      text: '市水务局：因违反《中华人民共和国水法》，受到县级以上人民政府水行政主管部门或者流域管理机构行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH006',
      text: '市水务局：因违反《中华人民共和国防洪法》，受到水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH007',
      text: '市水务局：因违反《中华人民共和国河道管理条例》，受到县级以上地方人民政府河道主管机关行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH008',
      text: '市水务局：因违反《四川省城市排水管理条例》，受到县级以上地方人民政府城市排水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH009',
      text:
        '市水务局：因违反《成都市市政工程设施管理条例》，受到市市政工程设施行政主管部门、区市政工程设施管理部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH010',
      text: '市水务局：因违反《成都市城市排水设施管理实施办法》，受到市市政工程主管部门或委托的单位行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH011',
      text: '市水务局：因违反《城镇排水与污水处理条例》，受到城镇排水主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH012',
      text: '市水务局：因违反《四川省城市节约用水管理办法》，受到城市建设行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH013',
      text: '市水务局：因违反《成都市节约用水管理条例》，受到水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH014',
      text: '市水务局：因违反《水库大坝安全管理条例》，受到大坝主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH015',
      text:
        '市水务局：因违反《四川省〈中华人民共和国水法〉实施办法》，受到县级以上水行政主管部门或流域管理机构行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH016',
      text: '市水务局：因违反《入河排污口监督管理办法》，受到县级以上地方人民政府行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH017',
      text: '市水务局：因违反《中华人民共和国水法》，受到县级以上地方人民政府经济综合主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH018',
      text:
        '市水务局：因违反《取水许可和水资源费征收管理条例》，受到县级以上地方人民政府水行政主管部门或者流域管理机构行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH019',
      text: '市水务局：因违反《成都市水资源管理条例》，受到当地水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH020',
      text: '市水务局：因违反《取水许可监督管理办法》，受到水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH021',
      text: '市水务局：因违反《四川省都江堰水利工程管理条例》，受到县级以上水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH022',
      text: '市水务局：因违反《四川省水利工程管理条例》，受到县级以上水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH023',
      text: '市水务局：因违反《中华人民共和国水土保持法》，受到县级人民政府水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH024',
      text:
        '市水务局：因违反《四川省〈中华人民共和国水土保持法〉实施办法》，受到县级以上地方人民政府水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH025',
      text: '市水务局：因违反《《建设项目水资源论证管理办法》，受到水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH026',
      text:
        '市水务局：因违反《开发建设项目水土保持方案编报审批管理规定》，受到县级以上人民政府水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH027',
      text: '市水务局：因违反《开发建设项目水土保持设施验收管理办法》，受到水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH028',
      text: '市水务局：因违反《水利工程质量事故处理暂行规定》，受到县以上水行政主管部门或经授权的流域机构行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH029',
      text: '市水务局：因违反《成都市地下水资源管理办法》，受到水行政主管部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH030',
      text: '市水务局：因违反《取水许可监督管理办法》，受到取水许可审批机关行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH031',
      text:
        '市水务局：因违反《中华人民共和国安全生产法》，受到安全生产监督管理部门和其他负有安全生产监督管理职责的部门行政处罚的'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SH032',
      text: '市水务局：因违反《四川省长江水源涵养保护条例》，受到县级以上人民政府有关部门行政处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'BZ', text: '市委编办' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'BZ001',
      text: '市委编办：因违反《事业单位登记管理暂行条例》，受到事业单位登记管理机关处罚的'
    },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CZ', text: '市财政局' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'CZ001', text: '市财政局：行政处罚' },
    { s_field_name: '违法行为类型', s_field: 'illegal_type', value: 'SJ', text: '市审计局' },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SJ001',
      text:
        '市审计局：对被审计单位拒绝或拖延提供与审计事项有关资料，或者提供的资料不真实、不完整的，或者拖延、拒绝、阻碍检查，拒不改正的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SJ002',
      text: '市审计局：对被审计单位违反国家规定的财务收支行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SJ003',
      text: '市审计局：对单位和个人截留、挪用、骗取国家建设资金，违反国家投资建设项目有关规定行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SJ004',
      text: '市审计局：对企业和个人隐瞒应当上缴的财政收入，截留代收的财政收入，及其他不缴或者少缴财政收入行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SJ005',
      text:
        '市审计局：对企业与个人骗取、挪用财政资金以及政府承贷或者担保的外国政府贷款、国际金融组织贷款，从无偿使用的财政资金以及政府承贷或者担保的外国政府贷款、国际金融组织贷款中非法获益，及其他违反规定使用、骗取财政资金以及其他政府承贷或者担保的外国政府贷款、国际金融组织贷款行为的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SJ006',
      text:
        '市审计局：对单位和个人违反规定印制财政收入票据，转借、串用、代开财政收入票据，伪造、变造、买卖、擅自销毁财政收入票据，伪造、使用伪造的财政收入票据监(印)制章的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SJ007',
      text: '市审计局：对单位和个人违反财务管理的规定，私存私放财政资金或者其他公款的处罚'
    },
    {
      s_field_name: '违法行为类型',
      s_field: 'illegal_type',
      value: 'SJ008',
      text: '市审计局：对建设单位或者代建单位未按规定提请办理竣工决(结)算审计的处罚'
    },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '1', text: '警告' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '2', text: '罚款' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '3', text: '没收违法所得、没收非法财物' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '4', text: '责令停产停业' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '5', text: '暂扣许可证' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '6', text: '暂扣执照' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '7', text: '吊销许可证' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '8', text: '吊销执照' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '9', text: '行政拘留' },
    { s_field_name: '处罚种类', s_field: 'PENALIZE_TYPE', value: '99', text: '法律、行政法规规定的其他行政处罚' },
    { s_field_name: '处罚执行情况', s_field: 'condition_type', value: '10', text: '已执行' },
    { s_field_name: '处罚执行情况', s_field: 'condition_type', value: '11', text: '正常执行' },
    { s_field_name: '处罚执行情况', s_field: 'condition_type', value: '12', text: '强制执行' },
    { s_field_name: '处罚执行情况', s_field: 'condition_type', value: '13', text: '分期(延期)执行' },
    { s_field_name: '处罚执行情况', s_field: 'condition_type', value: '20', text: '未执行' },
    { s_field_name: '处罚执行情况', s_field: 'condition_type', value: '21', text: '部分未执行' },
    { s_field_name: '处罚执行情况', s_field: 'condition_type', value: '22', text: '全部未执行' },
    { s_field_name: '未执行原因类别', s_field: 'uncondition_type', value: '1', text: '当事人无履行能力' },
    { s_field_name: '未执行原因类别', s_field: 'uncondition_type', value: '2', text: '违法款物失控' },
    { s_field_name: '未执行原因类别', s_field: 'uncondition_type', value: '3', text: '有关部门不配合' },
    { s_field_name: '未执行原因类别', s_field: 'uncondition_type', value: '4', text: '当事人不配合' },
    { s_field_name: '未执行原因类别', s_field: 'uncondition_type', value: '5', text: '当事人失踪' },
    { s_field_name: '未执行原因类别', s_field: 'uncondition_type', value: '9', text: '其他' },
    { s_field_name: '企业级别代码', s_field: 'OWN_TO', value: '2', text: '中央' },
    { s_field_name: '企业级别代码', s_field: 'OWN_TO', value: '3', text: '省属' },
    { s_field_name: '企业级别代码', s_field: 'OWN_TO', value: '99', text: '其它' },
    { s_field_name: '企业级别代码', s_field: 'OWN_TO', value: '6', text: '街道、镇、乡' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: '1', text: '货币' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: '2', text: '实物' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: '3', text: '知识产权' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: '9', text: '债权' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: '8', text: '高新技术成果' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: '4', text: '土地使用权' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: '7', text: '股权' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: '5', text: '劳务' },
    { s_field_name: '出资方式代码', s_field: 'CON_FORM', value: 'X', text: '其他' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '10', text: '法人股东' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '11', text: '企业法人' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '12', text: '事业法人' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '13', text: '社团法人' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '14', text: '机关法人' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '15', text: '外商投资企业' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '20', text: '自然人股东' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '21', text: '农民自然人' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '22', text: '非农民自然人' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '30', text: '外国(地区)投资者' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '31', text: '外国(地区)企业' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '32', text: '外国(地区)经济组织' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '33', text: '外商投资投资性公司' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '34', text: '外商投资创业投资企业' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '35', text: '外籍自然人' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '36', text: '华侨' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '40', text: '合伙企业' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '50', text: '个人独资企业' },
    { s_field_name: '投资人类型', s_field: 'STD_INV_NATURE', value: '90', text: '其他投资者' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ABW', text: '阿鲁巴' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'AFG', text: '阿富汗' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'AGO', text: '安哥拉' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'AIA', text: '安圭拉' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ALB', text: '阿尔巴尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'AND', text: '安道尔' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ANT', text: '荷属安的列斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ARE', text: '阿联酋' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ARG', text: '阿根廷' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ARM', text: '亚美尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ASM', text: '美属萨摩亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ATA', text: '南极洲' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ATF', text: '法属南部领土' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ATG', text: '安提瓜和巴布达' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'AUS', text: '澳大利亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'AUT', text: '奥地利' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'AZE', text: '阿塞拜疆' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BDI', text: '布隆迪' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BEL', text: '比利时' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BEN', text: '贝宁' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BFA', text: '布基纳法索' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BGD', text: '孟加拉国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BGR', text: '保加利亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BHR', text: '巴林' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BHS', text: '巴哈马' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BIH', text: '波黑' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BLR', text: '白俄罗斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BLZ', text: '伯利兹' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BMU', text: '百慕大' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BOL', text: '玻利维亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BRA', text: '巴西' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BRB', text: '巴巴多斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BRN', text: '文莱' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BTN', text: '不丹' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BVT', text: '布维岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'BWA', text: '博茨瓦纳' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CAF', text: '中非' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CAN', text: '加拿大' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CCK', text: '科科斯(基林)群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CHE', text: '瑞士' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CHL', text: '智利' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CHN', text: '中国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CIV', text: '科特迪瓦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CMR', text: '喀麦隆' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'COD', text: '刚果(金)' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'COG', text: '刚果(布)' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'COK', text: '库克群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'COL', text: '哥伦比亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'COM', text: '科摩罗' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CPV', text: '佛得角' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CRI', text: '哥斯达黎加' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CUB', text: '古巴' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CXR', text: '圣诞岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CYM', text: '开曼群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CYP', text: '塞浦路斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'CZE', text: '捷克' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'DEU', text: '德国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'DJI', text: '吉布提' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'DMA', text: '多米尼克' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'DNK', text: '丹麦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'DOM', text: '多米尼加共和国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'DZA', text: '阿尔及利亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ECU', text: '厄瓜多尔' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'EGY', text: '埃及' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ERI', text: '厄立特里亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ESH', text: '西撒哈拉' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ESP', text: '西班牙' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'EST', text: '爱沙尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ETH', text: '埃塞俄比亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'FIN', text: '芬兰' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'FJI', text: '斐济' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'FLK', text: '福克兰群岛(马尔维纳斯)' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'FRA', text: '法国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'FRO', text: '法罗群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'FSM', text: '密克罗尼西亚联邦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GAB', text: '加蓬' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GBR', text: '英国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GEO', text: '格鲁吉亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GHA', text: '加纳' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GIB', text: '直布罗陀' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GIN', text: '几内亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GLP', text: '瓜德罗普' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GMB', text: '冈比亚Gambia' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GNB', text: '几内亚比绍' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GNQ', text: '赤道几内亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GRC', text: '希腊' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GRD', text: '格林纳达' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GRL', text: '格陵兰' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GTM', text: '危地马拉' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GUF', text: '法属圭亚那' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GUM', text: '关岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'GUY', text: '圭亚那' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'HKG', text: '香港' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'HMD', text: '赫德岛和麦克唐纳岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'HND', text: '洪都拉斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'HRV', text: '克罗地亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'HTI', text: '海地' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'HUN', text: '匈牙利' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'IDN', text: '印度尼西亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'IND', text: '印度' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'IOT', text: '英属印度洋领土' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'IRL', text: '爱尔兰' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'IRN', text: '伊朗' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'IRQ', text: '伊拉克' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ISL', text: '冰岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ISR', text: '以色列' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ITA', text: '意大利' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'JAM', text: '牙买加' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'JOR', text: '约旦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'JPN', text: '日本' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'KAZ', text: '哈萨克斯坦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'KEN', text: '肯尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'KGZ', text: '吉尔吉斯斯坦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'KHM', text: '柬埔寨' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'KIR', text: '基里巴斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'KNA', text: '圣基茨和尼维斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'KOR', text: '韩国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'KWT', text: '科威特' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LAO', text: '老挝' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LBN', text: '黎巴嫩' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LBR', text: '利比里亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LBY', text: '利比亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LCA', text: '圣卢西亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LIE', text: '列支敦士登' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LKA', text: '斯里兰卡' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LSO', text: '莱索托' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LTU', text: '立陶宛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LUX', text: '卢森堡' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'LVA', text: '拉脱维亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MAC', text: '澳门' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MAR', text: '摩洛哥' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MCO', text: '摩纳哥' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MDA', text: '摩尔多瓦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MDG', text: '马达加斯加' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MDV', text: '马尔代夫' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MEX', text: '墨西哥' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MHL', text: '马绍尔群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MKD', text: '前南马其顿' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MLI', text: '马里' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MLT', text: '马耳他' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MMR', text: '缅甸' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MNG', text: '蒙古' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MNP', text: '北马里亚纳' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MOZ', text: '莫桑比克' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MRT', text: '毛里塔尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MSR', text: '蒙特塞拉特' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MTQ', text: '马提尼克' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MUS', text: '毛里求斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MWI', text: '马拉维' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MYS', text: '马来西亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'MYT', text: '马约特' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NAM', text: '纳米比亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NCL', text: '新喀里多尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NER', text: '尼日尔' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NFK', text: '诺福克岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NGA', text: '尼日利亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NIC', text: '尼加拉瓜' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NIU', text: '纽埃' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NLD', text: '荷兰' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NOR', text: '挪威' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NPL', text: '尼泊尔' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NRU', text: '瑙鲁' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'NZL', text: '新西兰' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'OMN', text: '阿曼' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PAK', text: '巴基斯坦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PAN', text: '巴拿马' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PCN', text: '皮特凯恩群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PER', text: '秘鲁' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PHL', text: '菲律宾' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PLW', text: '帕劳' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PNG', text: '巴布亚新几内亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'POL', text: '波兰' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PRI', text: '波多黎各' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PRK', text: '朝鲜' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PRT', text: '葡萄牙' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PRY', text: '巴拉圭' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PSE', text: '巴勒斯坦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'PYF', text: '法属波利尼西亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'QAT', text: '卡塔尔' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'REU', text: '留尼汪' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ROM', text: '罗马尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'RUS', text: '俄罗斯联邦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'RWA', text: '卢旺达' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SAU', text: '沙特阿拉伯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SDN', text: '苏丹' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SEN', text: '塞内加尔' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SGP', text: '新加坡' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SGS', text: '南乔治亚岛和南桑德韦奇岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SHN', text: '圣赫勒拿' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SJM', text: '斯瓦尔巴群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SLB', text: '所罗门群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SLE', text: '塞拉利昂' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SLV', text: '萨尔多瓦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SMR', text: '圣马力诺' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SOM', text: '索马里' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SPM', text: '圣皮埃尔和密克隆' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'STP', text: '圣多美和普林西比' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SUR', text: '苏里南' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SVK', text: '斯洛伐克' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SVN', text: '斯洛文尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SWE', text: '瑞典' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SWZ', text: '斯威士兰' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SYC', text: '塞舌尔' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'SYR', text: '叙利亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TCA', text: '特克斯科斯群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TCD', text: '乍得' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TGO', text: '多哥' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'THA', text: '泰国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TJK', text: '塔吉克斯坦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TKL', text: '托克劳' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TKM', text: '土库曼斯坦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TMP', text: '东帝汶' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TON', text: '汤加' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TTO', text: '特立尼达和多巴哥' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TUN', text: '突尼斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TUR', text: '土耳其' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TUV', text: '图瓦卢' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TWN', text: '台湾' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'TZA', text: '坦桑尼亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'UGA', text: '乌干达' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'UKR', text: '乌克兰' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'UMI', text: '美国本土外小岛屿' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'URY', text: '乌拉圭' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'USA', text: '美国' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'UZB', text: '乌兹别克斯坦' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'VAT', text: '梵蒂冈' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'VCT', text: '圣文森特和格林纳丁斯' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'VEN', text: '委内瑞拉' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'VGB', text: '英属维尔京群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'VIR', text: '美属维尔京群岛' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'VNM', text: '越南' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'VUT', text: '瓦努阿图' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'WLF', text: '瓦利斯和富图纳' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'WSM', text: '萨摩亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'YEM', text: '也门' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ZAF', text: '南非' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ZMB', text: '赞比亚' },
    { s_field_name: '国家(地区)代码', s_field: 'COUNTRY', value: 'ZWE', text: '津巴布韦' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'AFA', text: '阿富汗尼' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ALL', text: '列克' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'DZD', text: '阿尔及利亚第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ADP', text: '安道尔比赛塔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'AON', text: '新克瓦查' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'AZM', text: '阿塞拜疆马纳特' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ARS', text: '阿根廷比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'AUD', text: '澳大利亚元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ATS', text: '奥地利先令' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BSD', text: '巴哈马元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BHD', text: '巴林第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BDT', text: '塔卡' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'AMD', text: '亚美尼亚达姆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BBD', text: '巴巴多斯元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BEF', text: '比利时法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BMD', text: '百慕大元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BTN', text: '努尔特鲁姆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BOB', text: '玻璃瓦诺' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BWP', text: '普拉' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BZD', text: '伯利兹元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SBD', text: '所罗门群岛元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BND', text: '文莱元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BGL', text: '列弗' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MMK', text: '缅元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BIF', text: '布隆迪法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KHR', text: '瑞尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CAD', text: '加元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CVE', text: '佛得角埃斯库多' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KYD', text: '开曼群岛元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LKR', text: '斯里兰卡卢比' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CLP', text: '智利比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CNY', text: '人民币' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'COP', text: '哥伦比亚比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KMF', text: '科摩罗法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CRC', text: '哥斯达黎加科郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'HRK', text: '克罗地亚库纳' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CUP', text: '古巴比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CYP', text: '塞浦路斯镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CZK', text: '捷克克郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'DKK', text: '丹麦克郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'DOP', text: '多米尼加比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SVC', text: '萨尔瓦多科郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ETB', text: '埃塞俄比亚比尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ERN', text: '纳克法' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'EEK', text: '克罗姆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'FKP', text: '福克兰群岛镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'FJD', text: '斐济元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'FIM', text: '马克' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'FRF', text: '法国法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'DJF', text: '吉布提法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GMD', text: '达拉西' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'DEM', text: '德国马克' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GHC', text: '塞地' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GIP', text: '直布罗陀镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GRD', text: '德拉克马' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GTQ', text: '格查尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GNF', text: '几内亚法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GYD', text: '圭亚那元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'HTG', text: '古德' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'HNL', text: '伦皮拉' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'HKD', text: '香港元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'HUF', text: '福林' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ISK', text: '冰岛克郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'INR', text: '印度卢比' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'IDR', text: '卢比' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'IRR', text: '伊朗里亚尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'IQD', text: '伊拉克第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'IEP', text: '爱尔兰镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ILS', text: '锡克尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ITL', text: '意大利里拉' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'JMD', text: '牙买加元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'JPY', text: '日元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KZT', text: '坚戈' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'JOD', text: '约旦第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KES', text: '肯尼亚先令' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KPW', text: '北朝鲜圆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KRW', text: '圆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KWD', text: '科威特第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'KGS', text: '索姆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LAK', text: '基普' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LBP', text: '黎巴嫩镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LSL', text: '罗提' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LVL', text: '拉托维亚拉特' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LRD', text: '利比里亚元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LYD', text: '利比亚第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LTL', text: '立陶宛' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'LUF', text: '卢森堡法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MOP', text: '澳门元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MGF', text: '马尔加什法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MWK', text: '克瓦查' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MYR', text: '马来西亚林吉特' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MVR', text: '卢菲亚' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MTL', text: '马尔他里拉' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MRO', text: '乌吉亚' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MUR', text: '毛里求斯卢比' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MXN', text: '墨西哥比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MNT', text: '图格里克' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MDL', text: '摩尔瓦多列伊' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MAD', text: '摩洛哥迪拉姆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MZM', text: '麦梯卡尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'OMR', text: '阿曼里亚尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'NAD', text: '纳米比亚元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'NPR', text: '尼泊尔卢比' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'NLG', text: '荷兰盾' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ANG', text: '荷属安的列斯盾' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'AWG', text: '阿鲁巴盾' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'VUV', text: '瓦图' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'NZD', text: '新西兰元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'NIO', text: '金科多巴' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'NGN', text: '奈拉' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'NOK', text: '挪威克郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'PKR', text: '巴基斯坦卢比' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'PAB', text: '巴波亚' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'PGK', text: '基那' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'PYG', text: '瓜拉尼' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'PEN', text: '索尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'PHP', text: '菲律宾比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'PTE', text: '葡萄牙埃斯库多' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GWP', text: '几内亚比绍比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TPE', text: '东帝汶埃斯库多' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'QAR', text: '卡塔尔里亚尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ROL', text: '列伊' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'RWF', text: '卢旺达法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SHP', text: '圣赫勒拿镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'STD', text: '多布拉' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SAR', text: '沙特里亚尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SCR', text: '塞舌尔卢比' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SLL', text: '利昂' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SGD', text: '新加坡元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SKK', text: '斯洛伐克克郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'VND', text: '盾' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SIT', text: '托拉尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SOS', text: '索马里先令' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ZAR', text: '兰特' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ZWD', text: '津巴布韦元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ESP', text: '西班牙比赛塔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SDD', text: '苏丹第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SRG', text: '苏里南盾' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SZL', text: '里兰吉尼' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SEK', text: '瑞典克郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CHF', text: '瑞士法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'SYP', text: '叙利亚镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'THB', text: '泰国铢' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TOP', text: '邦加' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TTD', text: '特立尼达和多巴哥元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'AED', text: 'UAE迪拉姆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TND', text: '突尼斯第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TRL', text: '土耳其里拉' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TMM', text: '马纳特' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'UGX', text: '乌干达先令' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MKD', text: '第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'RUB', text: '俄罗斯卢布' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'EGP', text: '埃及镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'GBP', text: '英镑' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TZS', text: '坦桑尼亚先令' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'USD', text: '美元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'UYU', text: '乌拉圭比索' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'UZS', text: '乌兹别克斯坦苏姆' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'VEB', text: '博利瓦' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'WST', text: '塔拉' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'YER', text: '也门里亚尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'YUN', text: '南斯拉夫第纳尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ZMK', text: '克瓦查' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TWD', text: '新台湾元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XAF', text: 'CFA法郎BEAC' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XCD', text: '东加勒比元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XOF', text: 'CFA法郎BCEAO' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XPF', text: 'CFP法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XBA', text: '欧洲货币合成单位(EURCO)' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XBB', text: '欧洲货币(单位EMU.-6)' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XBC', text: '欧洲账户9单位(E.U.A.-9)' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XBD', text: '欧洲账户17单位(E.U.A.-17)' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XAU', text: '黄金' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XDR', text: '特别提款权' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XAG', text: '银' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XPT', text: '铂白金' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XTS', text: '为测试特别保留的代码' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'XPD', text: '钯' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'TJS', text: '索莫尼' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BYR', text: '白俄罗斯卢布' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BGN', text: '保加利亚列弗' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CDF', text: '刚果法郎' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BAM', text: '可自由兑换标记' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'EUR', text: '欧元' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'MXV', text: '墨西哥发展单位' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'UAH', text: '格里夫纳' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BOV', text: 'Mvdol' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'PLN', text: '兹罗提' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'BRL', text: '巴西瑞尔' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'CLF', text: '发展单位' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'USN', text: '美元次日' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'USS', text: '美元同日' },
    { s_field_name: '币种代码', s_field: 'CURRENCY', value: 'ASF', text: '记账瑞士法郎' },
    //新增公司章程数据字典
    { s_field_name: '股东与股东大会', s_field: 'share_holder', value: 'sh_hold_1', text: '股东权利及义务' },
    { s_field_name: '股东与股东大会', s_field: 'share_holder', value: 'sh_hold_2', text: '股东(大)会规定及职权' },
    {
      s_field_name: '股东与股东大会',
      s_field: 'share_holder',
      value: 'sh_hold_3',
      text: '股东(大)会会议的召集召开提案与通知'
    },
    { s_field_name: '股东与股东大会', s_field: 'share_holder', value: 'sh_hold_4', text: '股东(大)会的表决与决议' },
    { s_field_name: '董监高', s_field: 'director', value: 'director_1', text: '董事要求/职权及义务' },
    { s_field_name: '董监高', s_field: 'director', value: 'director_2', text: '董事会职权及规定' },
    { s_field_name: '董监高', s_field: 'director', value: 'director_3', text: '监事要求/职权及义务' },
    { s_field_name: '董监高', s_field: 'director', value: 'director_4', text: '监事会职权及规定' },
    { s_field_name: '董监高', s_field: 'director', value: 'director_5', text: '总经理及其他高级管理人员' },
    {
      s_field_name: '公司合并、分离、解散和清算',
      s_field: 'company',
      value: 'company_1',
      text: '公司合并、分离、解散和清算'
    },
    {
      s_field_name: '财务会计制度利润分配和内部审计',
      s_field: 'finance',
      value: 'finance_1',
      text: '财务会计制度、利润分配和内部审计'
    },
    /*****************************新增对公客户* 开始 *********************************************/
    //新增对公客户证件类型
    { s_field_name: '新增对公客户证件类型', s_field: 'STD_ZB_CERT_TYP', value: '20', text: '组织机构代码' },
    { s_field_name: '新增对公客户证件类型', s_field: 'STD_ZB_CERT_TYP', value: '26', text: '统一社会信用代码' },
    //新增对公客户类型
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '211', text: '企业法人' },
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '212', text: '企业非法人' },
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '221', text: '事业单位' },
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '231', text: '社会团体' },
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '241', text: '党政机关' },
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '250', text: '镇，村经济组织' },
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '260', text: '个体工商户' },
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '243', text: '其他机构' },
    { s_field_name: '新增对公客户类型', s_field: 'STD_ZB_CUS_TYPE', value: '299', text: '非企业法人' },
    /*****************************新增对公客户* 结束 *********************************************/
    /*****************************综合收益率试算录入* 开始 *********************************************/
    //客户评级
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '11', text: 'AAA' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '12', text: 'AA+' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '13', text: 'AA' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '14', text: 'AA-' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '15', text: 'A+' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '16', text: 'A' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '17', text: 'A-' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '20', text: 'BBB+' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '21', text: 'BBB' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '22', text: 'BBB-' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '23', text: 'BB+' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '24', text: 'BB' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '25', text: 'B' },
    { s_field_name: '客户评级', s_field: 'STD_ZB_CREDIT_GRADE', value: '40', text: 'D' },
    //拟贷款期限类型
    { s_field_name: '拟贷款期限类型', s_field: 'LOAN_TERM_TYPE', value: '3M', text: '3个月以内(含)' },
    { s_field_name: '拟贷款期限类型', s_field: 'LOAN_TERM_TYPE', value: '6M', text: '3-6个月(含)' },
    { s_field_name: '拟贷款期限类型', s_field: 'LOAN_TERM_TYPE', value: '1Y', text: '6个月-1年(含)' },
    { s_field_name: '拟贷款期限类型', s_field: 'LOAN_TERM_TYPE', value: '2Y', text: '1-2年(含)' },
    { s_field_name: '拟贷款期限类型', s_field: 'LOAN_TERM_TYPE', value: '3Y', text: '2-3年(含)' },
    { s_field_name: '拟贷款期限类型', s_field: 'LOAN_TERM_TYPE', value: '4Y', text: '3-4年(含)' },
    { s_field_name: '拟贷款期限类型', s_field: 'LOAN_TERM_TYPE', value: '5Y', text: '4-5年(含)' },
    { s_field_name: '拟贷款期限类型', s_field: 'LOAN_TERM_TYPE', value: 'N', text: '5年以上' },
    //拟存款期限类型
    { s_field_name: '拟存款期限类型', s_field: 'DEP_TERM_TYPE', value: '10001', text: '3个月' },
    { s_field_name: '拟存款期限类型', s_field: 'DEP_TERM_TYPE', value: '10002', text: '6个月' },
    { s_field_name: '拟存款期限类型', s_field: 'DEP_TERM_TYPE', value: '10003', text: '一年' },
    { s_field_name: '拟存款期限类型', s_field: 'DEP_TERM_TYPE', value: '10004', text: '三年' },
    { s_field_name: '拟存款期限类型', s_field: 'DEP_TERM_TYPE', value: '10005', text: '五年' },
    { s_field_name: '拟存款期限类型', s_field: 'DEP_TERM_TYPE', value: '10006', text: '其他' },
    /*****************************综合收益率试算录入* 结束 *********************************************/
    /*****************************个人电话营销* 开始 *********************************************/
    //个人电话营销营销结果
    { s_field_name: '个人电话营销营销结果', s_field: 'TelMarketingResult', value: '0100', text: '电话未接听' },
    { s_field_name: '个人电话营销营销结果', s_field: 'TelMarketingResult', value: '0200', text: '非本人电话' },
    { s_field_name: '个人电话营销营销结果', s_field: 'TelMarketingResult', value: '0300', text: '接起后直接挂断' },
    { s_field_name: '个人电话营销营销结果', s_field: 'TelMarketingResult', value: '0400', text: '关机' },
    {
      s_field_name: '个人电话营销营销结果',
      s_field: 'TelMarketingResult',
      value: '0500',
      text: '不愿意听，回复不需要'
    },
    { s_field_name: '个人电话营销营销结果', s_field: 'TelMarketingResult', value: '0600', text: '有意向办理' },
    { s_field_name: '个人电话营销营销结果', s_field: 'TelMarketingResult', value: '0700', text: '其他' },
    //个人电话营销作废原因
    { s_field_name: '个人电话营销作废原因', s_field: 'DhyxRefuse', value: '2', text: '不符合准入条件' },
    { s_field_name: '个人电话营销作废原因', s_field: 'DhyxRefuse', value: '1', text: '营销客群范围选择错误' },
    //个人电话营销退回原因
    { s_field_name: '个人电话营销退回原因', s_field: 'TelTaskBackReason', value: '0001', text: '工作任务待重新分配' },
    //个人电话营销客户类型
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9010',
      text: '存量按揭客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9020',
      text: '优易贷存量激活客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9030',
      text: '随意分存量激活客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9040',
      text: '优易贷存量未续客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9050',
      text: '随意分存量未续客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9060',
      text: '以往被拒客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9070',
      text: '点击优易贷查看额度客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9080',
      text: '到期续贷客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9090',
      text: '额度过期客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '9095',
      text: '额度即将到期客户'
    },
    { s_field_name: '个人电话营销客户类型', s_field: 'TelMarketingCustomerType', value: '0100', text: '按揭客户' },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0110',
      text: '有代发但单位未入围优易贷客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0120',
      text: '有代发且单位已入围优易贷客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0130',
      text: '无代发但单位入围优易贷客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0140',
      text: '优易贷存量激活客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0150',
      text: '随意分存量激活客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0160',
      text: '优易贷存量未续客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0170',
      text: '随意分存量未续客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0180',
      text: '以往被拒客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0190',
      text: '点击优易贷查看额度客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0200',
      text: '到期续贷客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0210',
      text: '公积金联名卡客户'
    },
    {
      s_field_name: '个人电话营销客户类型',
      s_field: 'TelMarketingCustomerType',
      value: '0220',
      text: '公积金**强客户'
    },
    /*****************************个人电话营销* 结束 *********************************************/
    //***********************************个贷催收和贷后 开始*****************************************
    //催收对象
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '借款人本人', value: '0101' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '共同还款人', value: '0103' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '共同借款人', value: '0104' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '借款人父母', value: '0105' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '借款人子女', value: '0106' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '关联企业会计', value: '0107' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '借款人同事', value: '0108' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '借款人下属', value: '0109' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '借款人朋友', value: '0110' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '其它', value: '0111' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '借款人配偶', value: '02' },
    { s_field_name: '催收对象', s_field: 'CONTACTORTYPE', text: '担保人', value: '03' },
    //催收方式
    { s_field_name: '催收方式', s_field: 'CONTACTMETHOD', value: '1', text: '短信催收' },
    { s_field_name: '催收方式', s_field: 'CONTACTMETHOD', value: '2', text: '电话催收' },
    { s_field_name: '催收方式', s_field: 'CONTACTMETHOD', value: '3', text: '上门催收' },
    { s_field_name: '催收方式', s_field: 'CONTACTMETHOD', value: '4', text: '信函催收' },
    { s_field_name: '催收方式', s_field: 'CONTACTMETHOD', value: '5', text: '外包催收' },
    { s_field_name: '催收方式', s_field: 'CONTACTMETHOD', value: '9', text: '其它' },
    //催收结果
    { s_field_name: '催收结果', s_field: 'CONTACTRESULT', value: '0301', text: '已上门，客户同意还款' },
    { s_field_name: '催收结果', s_field: 'CONTACTRESULT', value: '0302', text: '已上门，客户提出异议' },
    { s_field_name: '催收结果', s_field: 'CONTACTRESULT', value: '0303', text: '已上门，客户报告特殊情况' },
    { s_field_name: '催收结果', s_field: 'CONTACTRESULT', value: '02', text: '已上门，客户本人不在' },
    { s_field_name: '催收结果', s_field: 'CONTACTRESULT', value: '0305', text: '已上门，无人在' },
    { s_field_name: '催收结果', s_field: 'CONTACTRESULT', value: '0306', text: '已上门，地址错误' },
    { s_field_name: '催收结果', s_field: 'CONTACTRESULT', value: '0399', text: '其它' },
    //客户解释
    { s_field_name: '客户解释', s_field: 'EXPLANATIONCODE', value: '01', text: '遗忘' },
    { s_field_name: '客户解释', s_field: 'EXPLANATIONCODE', value: '02', text: '离家' },
    { s_field_name: '客户解释', s_field: 'EXPLANATIONCODE', value: '03', text: '经济困难' },
    { s_field_name: '客户解释', s_field: 'EXPLANATIONCODE', value: '04', text: '房屋问题' },
    { s_field_name: '客户解释', s_field: 'EXPLANATIONCODE', value: '05', text: '车辆问题' },
    { s_field_name: '客户解释', s_field: 'EXPLANATIONCODE', value: '06', text: '家庭问题' },
    { s_field_name: '客户解释', s_field: 'EXPLANATIONCODE', value: '07', text: '其它' },
    //电话簿
    //与联系人关系
    { s_field_name: '与联系人关系', s_field: 'RELATIONSHIP', text: '关联企业会计', value: '0107' },
    { s_field_name: '与联系人关系', s_field: 'RELATIONSHIP', text: '借款人同事', value: '0108' },
    { s_field_name: '与联系人关系', s_field: 'RELATIONSHIP', text: '借款人下属', value: '0109' },
    { s_field_name: '与联系人关系', s_field: 'RELATIONSHIP', text: '借款人朋友', value: '0110' },
    { s_field_name: '与联系人关系', s_field: 'RELATIONSHIP', text: '其它', value: '0111' },
    //电话类型
    { s_field_name: '电话类型', s_field: 'TELTYPE', text: '手机号码', value: '1' },
    { s_field_name: '电话类型', s_field: 'TELTYPE', text: '单位电话', value: '2' },
    { s_field_name: '电话类型', s_field: 'TELTYPE', text: '住宅电话', value: '3' },
    { s_field_name: '电话类型', s_field: 'TELTYPE', text: '传真电话', value: '4' },
    { s_field_name: '电话类型', s_field: 'TELTYPE', text: '紧急联系方式', value: '5' },
    //是否最新
    { s_field_name: '是否最新', s_field: 'ISNEW', text: '是', value: '1' },
    { s_field_name: '是否最新', s_field: 'ISNEW', text: '否', value: '2' },
    //贷后检查结论
    { s_field_name: '检查结论', s_field: 'result_type', text: '正常维护', value: '1' },
    { s_field_name: '检查结论', s_field: 'result_type', text: '加强监控', value: '2' },
    { s_field_name: '检查结论', s_field: 'result_type', text: '风险预警', value: '3' },
    { s_field_name: '检查结论', s_field: 'result_type', text: '下调风险分类', value: '4' },
    { s_field_name: '检查结论', s_field: 'result_type', text: '加入黑名单', value: '5' },
    { s_field_name: '检查结论', s_field: 'result_type', text: '加入灰名单', value: '6' },
    { s_field_name: '检查结论', s_field: 'result_type', text: '介入催收', value: '7' },
    { s_field_name: '检查结论', s_field: 'result_type', text: '面作本次检查', value: '8' },
    //催收等级
    { s_field_name: '催收等级', s_field: 'COLLECTIONLEVEL', text: 'A', value: 'A' },
    { s_field_name: '催收等级', s_field: 'COLLECTIONLEVEL', text: 'B', value: 'B' },
    { s_field_name: '催收等级', s_field: 'COLLECTIONLEVEL', text: 'C', value: 'C' },
    { s_field_name: '催收等级', s_field: 'COLLECTIONLEVEL', text: 'D', value: 'D' },
    { s_field_name: '催收等级', s_field: 'COLLECTIONLEVEL', text: 'E', value: 'E' },
    //贷后检查类型
    { s_field_name: '贷后检查类型', s_field: 'INSPECTTYPE', text: '房屋按揭业务贷款检查', value: '01' },
    { s_field_name: '贷后检查类型', s_field: 'INSPECTTYPE', text: '资金用途检查', value: '02' },
    { s_field_name: '贷后检查类型', s_field: 'INSPECTTYPE', text: '经营类贷款检查', value: '03' },
    { s_field_name: '贷后检查类型', s_field: 'INSPECTTYPE', text: '消费类贷款检查', value: '04' },
    //检查结论(业务类)
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '正常维护', value: '01' },
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '加强监控', value: '02' },
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '风险预警', value: '03' },
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '改变检查频率', value: '04' },
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '下调风险分类', value: '05' },
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '加入黑名单', value: '06' },
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '加入灰名单', value: '07' },
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '介入催收', value: '08' },
    { s_field_name: '检查结论', s_field: 'INSPECTATION', text: '免做本次检查', value: '09' },
    //检查结论(合作项目)
    { s_field_name: '检查结论', s_field: 'CheckResult', text: '正常维护', value: '01' },
    { s_field_name: '检查结论', s_field: 'CheckResult', text: '加强监控', value: '02' },
    { s_field_name: '检查结论', s_field: 'CheckResult', text: '风险预警', value: '03' },
    { s_field_name: '检查结论', s_field: 'CheckResult', text: '暂停合作', value: '05' },
    { s_field_name: '检查结论', s_field: 'CheckResult', text: '停止合作', value: '06' },
    //网贷随意分类别
    { s_field_name: '检查结论', s_field: 'SYFINSPECTATION', text: '正常维护', value: '01' },
    { s_field_name: '检查结论', s_field: 'SYFINSPECTATION', text: '加强监控', value: '02' },
    { s_field_name: '检查结论', s_field: 'SYFINSPECTATION', text: '风险预警', value: '03' },
    //***********************************个贷催收和贷后 结束*****************************************
    //***********************************信贷 风险和贷后 开始*****************************************
    //解除方式 s_field_name: '解除下次推送时间', s_field: 'next_date_type',
    { s_field_name: '解除方式', s_field: 'release_type', value: '10', text: '自动解除' },
    { s_field_name: '解除方式', s_field: 'release_type', value: '20', text: '人工解除' },
    { s_field_name: '解除方式', s_field: 'release_type', value: '30', text: '不解除' },
    //解除下次推送时间
    { s_field_name: '解除下次推送时间', s_field: 'next_date_type', value: '05', text: 'T+1' },
    { s_field_name: '解除下次推送时间', s_field: 'next_date_type', value: '10', text: 'T+7' },
    { s_field_name: '解除下次推送时间', s_field: 'next_date_type', value: '20', text: 'T+14' },
    { s_field_name: '解除下次推送时间', s_field: 'next_date_type', value: '30', text: 'T+30' },
    { s_field_name: '解除下次推送时间', s_field: 'next_date_type', value: '40', text: 'T+60' },
    { s_field_name: '解除下次推送时间', s_field: 'next_date_type', value: '50', text: 'T+90' },
    { s_field_name: '解除下次推送时间', s_field: 'next_date_type', value: '60', text: '不再推送' },
    //任务状态
    { s_field_name: "任务状态", s_field: "task_status", value: "10", text: "未处理" },
    { s_field_name: "任务状态", s_field: "task_status", value: "20", text: "已处理" },
    { s_field_name: "任务状态", s_field: "task_status", value: "30", text: "自动终止" },
    //审批状态
    { s_field_name: "审批状态", s_field: "approve_status", value: '000', text: '待发起' },
    { s_field_name: "审批状态", s_field: "approve_status", value: '111', text: '审批中' },
    { s_field_name: "审批状态", s_field: "approve_status", value: '991', text: '追回' },
    { s_field_name: "审批状态", s_field: "approve_status", value: '992', text: '打回' },
    { s_field_name: "审批状态", s_field: "approve_status", value: '993', text: '重报' },
    //检查状态
    { s_field_name: "检查状态", s_field: "check_status", value: '01', text: '待处理' },
    { s_field_name: "检查状态", s_field: "check_status", value: '02', text: '处理中' },
    { s_field_name: "检查状态", s_field: "check_status", value: '03', text: '已处理' },
    { s_field_name: "检查状态", s_field: "check_status", value: '05', text: '未处理' },
    { s_field_name: "检查状态", s_field: "check_status", value: '06', text: '无需处理' },
    { s_field_name: "检查状态", s_field: "check_status", value: '09', text: '检查完成' },
    { s_field_name: "检查状态", s_field: "check_status", value: '10', text: '作废' },
    //待办检查状态
    { s_field_name: "待办检查状态", s_field: "up_check_status", value: '01', text: '待处理' },
    { s_field_name: "待办检查状态", s_field: "up_check_status", value: '02', text: '处理中' },
    //***********************************信贷 风险和贷后 结束*****************************************
    //***********************************辅助功能开始*****************************************
    //还款方式
    { s_field_name: '还款方式', s_field: 'Repayment', value: '1', text: '按月摊销本金' },
    { s_field_name: '还款方式', s_field: 'Repayment', value: '2', text: '到期还本' },
    //手续费收取方式
    { s_field_name: '手续费收取方式', s_field: 'brokerage', value: '1', text: '首期全额支付手续费' },
    { s_field_name: '手续费收取方式', s_field: 'brokerage', value: '2', text: '按月等额支付手续费' },
    //证件类型选择
    { s_field_name: '输入证件类型', s_field: 'IdentTp', value: '1', text: '组织机构代码' },
    { s_field_name: '输入证件类型', s_field: 'IdentTp', value: '2', text: '统一社会信用代码' },
    //贷款试算类型
    { s_field_name: '贷款试算类型', s_field: 'refundType', value: '等额本金', text: '等额本金' },
    { s_field_name: '贷款试算类型', s_field: 'refundType', value: '等额本息', text: '等额本息' },
    { s_field_name: '贷款试算类型', s_field: 'refundType', value: '按月付息', text: '按月付息' },
    //随意分按月期限
    { s_field_name: '随意分按月期限', s_field: 'NUM', value: '12', text: '12' },
    { s_field_name: '随意分按月期限', s_field: 'NUM', value: '24', text: '24' },
    { s_field_name: '随意分按月期限', s_field: 'NUM', value: '36', text: '36' },
    { s_field_name: '随意分按月期限', s_field: 'NUM', value: '48', text: '48' },
    { s_field_name: '随意分按月期限', s_field: 'NUM', value: '60', text: '60' },
    //***********************************辅助功能结束*****************************************
    //意见反馈
    { s_field_name: '意见反馈', s_field: 'YJFK', value: '1', text: '产品问题' },
    { s_field_name: '意见反馈', s_field: 'YJFK', value: '2', text: '系统使用问题' },
    { s_field_name: '意见反馈', s_field: 'YJFK', value: '3', text: '业务服务问题' },
    { s_field_name: '意见反馈', s_field: 'YJFK', value: '3', text: '其他' },
    //***********************************短信类型开始*****************************************
    //短信场景识别码
    {
      s_field_name: '短信场景识别码',
      s_field: 'SendMessageCode',
      value: 'S2022011910484099',
      text: '优易贷预授信提用'
    },
    {
      s_field_name: '短信场景识别码',
      s_field: 'SendMessageCode',
      value: 'S2022011910491168',
      text: '随意分已批未提'
    },
    {
      s_field_name: '短信场景识别码',
      s_field: 'SendMessageCode',
      value: 'S2022011910493181',
      text: '随意分申请邀请'
    },
    //***********************************短信类型结束*****************************************
    //性别
    { s_field_name: '性别', s_field: 'sex', value: '0', text: '全部' },
    { s_field_name: '性别', s_field: 'sex', value: '1', text: '男' },
    { s_field_name: '性别', s_field: 'sex', value: '2', text: '女' },
    //客户状态
    { s_field_name: '客户状态', s_field: 'custState', value: '00', text: '正式客户(预登记状态)' },
    { s_field_name: '客户状态', s_field: 'custState', value: '20', text: '正式客户' },
    { s_field_name: '客户状态', s_field: 'custState', value: '70', text: '潜在客户' },
    { s_field_name: '客户状态', s_field: 'custState', value: '71', text: '潜在客户(预登记状态)' },
    { s_field_name: '客户状态', s_field: 'custState', value: 'CA', text: '待补录客户' },
    //客户类型
    { s_field_name: '客户类型', s_field: 'custType', value: '999', text: '待补录客户' },
    { s_field_name: '客户类型', s_field: 'custType', value: '211', text: '企业法人' },
    { s_field_name: '客户类型', s_field: 'custType', value: '212', text: '企业非法人' },
    { s_field_name: '客户类型', s_field: 'custType', value: '221', text: '事业单位' },
    { s_field_name: '客户类型', s_field: 'custType', value: '231', text: '社会团体' },
    { s_field_name: '客户类型', s_field: 'custType', value: '241', text: '党政机关' },
    { s_field_name: '客户类型', s_field: 'custType', value: '250', text: '镇，村经济组织' },
    { s_field_name: '客户类型', s_field: 'custType', value: '260', text: '个体工商户' },
    { s_field_name: '客户类型', s_field: 'custType', value: '299', text: '其他机构' },
    { s_field_name: '客户类型', s_field: 'custType', value: '243', text: '非企业法人' },
    //对公营销任务类型
    { s_field_name: '对公营销任务类型', s_field: 'marketType', value: '1', text: '对公客户拜访营销任务' },
    { s_field_name: '对公营销任务类型', s_field: 'marketType', value: '2', text: '招商引资企业营销台账任务' },
    { s_field_name: '对公营销任务类型', s_field: 'marketType', value: '3', text: '公司精准信息摸排专项营销任务' },
    { s_field_name: '对公营销任务类型', s_field: 'marketType', value: '4', text: '精准营销专项对公营销任务' },
    //营销方式
    { s_field_name: '营销方式', s_field: 'marketMode', value: '1', text: '驻点宣传' },
    { s_field_name: '营销方式', s_field: 'marketMode', value: '2', text: '一对一办理' },
    { s_field_name: '营销方式', s_field: 'marketMode', value: '3', text: '流动扫楼' },
    { s_field_name: '营销方式', s_field: 'marketMode', value: '4', text: '产品宣讲会' },
    //渠道类型
    { s_field_name: '渠道类型', s_field: 'cerType', value: '1', text: '优质代发' },
    { s_field_name: '渠道类型', s_field: 'cerType', value: '2', text: '公司线条' },
    { s_field_name: '渠道类型', s_field: 'cerType', value: '3', text: '员工资源' },
    //续贷审批权限
    { s_field_name: '续贷审批权限', s_field: 'xdSpQx', value: '1', text: '分支机构权限内' },
    { s_field_name: '续贷审批权限', s_field: 'xdSpQx', value: '2', text: '分支机构权限外' },
    //续贷业务类型
    { s_field_name: '续贷业务类型', s_field: 'xdYwLx', value: '1', text: '一般贷款' },
    { s_field_name: '续贷业务类型', s_field: 'xdYwLx', value: '2', text: '银承' },
    { s_field_name: '续贷业务类型', s_field: 'xdYwLx', value: '3', text: '贴现' },
    { s_field_name: '续贷业务类型', s_field: 'xdYwLx', value: '4', text: '保函' },
    //担保方式
    { s_field_name: '担保方式', s_field: 'dbFs', value: '1', text: '信用' },
    { s_field_name: '担保方式', s_field: 'dbFs', value: '2', text: '抵押' },
    { s_field_name: '担保方式', s_field: 'dbFs', value: '3', text: '质押' },
    { s_field_name: '担保方式', s_field: 'dbFs', value: '4', text: '保证' },
    //续贷业务进度
    { s_field_name: '续贷业务进度', s_field: 'xdYwJd', value: '1', text: '调查中' },
    { s_field_name: '续贷业务进度', s_field: 'xdYwJd', value: '2', text: '审批中' },
    { s_field_name: '续贷业务进度', s_field: 'xdYwJd', value: '3', text: '已审批通过' },
    { s_field_name: '续贷业务进度', s_field: 'xdYwJd', value: '4', text: '已签订合同' },
    { s_field_name: '续贷业务进度', s_field: 'xdYwJd', value: '5', text: '待放款' },
    { s_field_name: '续贷业务进度', s_field: 'xdYwJd', value: '6', text: '已放款' },
    /*****************************对公营销* 开始 *********************************************/
    //是、否、待定
    { s_field_name: '是、否、待定', s_field: 'YesOrNoOrUnd', value: '1', text: '是' },
    { s_field_name: '是、否、待定', s_field: 'YesOrNoOrUnd', value: '2', text: '否' },
    { s_field_name: '是、否、待定', s_field: 'YesOrNoOrUnd', value: '3', text: '待定' },
    //是、否
    { s_field_name: '是、否', s_field: 'YesOrNo', value: '1', text: '是' },
    { s_field_name: '是、否', s_field: 'YesOrNo', value: '2', text: '否' },
    //客户分类
    { s_field_name: '客户分类', s_field: 'CUSTOMER_CLASS', value: '1', text: '存量公司精准客户' },
    { s_field_name: '客户分类', s_field: 'CUSTOMER_CLASS', value: '2', text: '新客户-公司精准名单内客户' },
    { s_field_name: '客户分类', s_field: 'CUSTOMER_CLASS', value: '3', text: '新客户-拟申报公司精准客户' },
    { s_field_name: '客户分类', s_field: 'CUSTOMER_CLASS', value: '4', text: '精准营销渠道建设' },
    //客户分类2
    { s_field_name: '客户分类2', s_field: 'customerType', value: '1', text: '新客户-拟报精准入围' },
    { s_field_name: '客户分类2', s_field: 'customerType', value: '2', text: '新客户-总行精准名单内' },
    { s_field_name: '客户分类2', s_field: 'customerType', value: '3', text: '存量精准客户-新增授信' },
    { s_field_name: '客户分类2', s_field: 'customerType', value: '4', text: '存量精准客户-还后续贷' },
    //控股类型
    { s_field_name: '控股类型', s_field: 'HOLDING_TYPE', value: '1', text: '央企' },
    { s_field_name: '控股类型', s_field: 'HOLDING_TYPE', value: '2', text: '省属国有单位' },
    { s_field_name: '控股类型', s_field: 'HOLDING_TYPE', value: '3', text: '市属国有企业' },
    { s_field_name: '控股类型', s_field: 'HOLDING_TYPE', value: '4', text: '非国有控股' },
    //客户行业
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '1', text: '医院' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '2', text: '医药' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '3', text: '教育' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '4', text: '军工' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '5', text: '城市服务(水、电、气等)' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '6', text: '饮料饮品(含酒类)' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '7', text: '电子信息' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '8', text: '新基建' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '9', text: '光伏' },
    { s_field_name: '客户行业', s_field: 'CUSTOMR_INDUSTRY_CLASS', value: '10', text: '其他' },
    //客户行业2
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '1', text: '医药制造业' },
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '2', text: '软件和信息服务业' },
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '3', text: 'IT、计算机硬件设备业' },
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '4', text: '航空、航天及船舶等制造业' },
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '5', text: '设备制造业' },
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '6', text: '水、燃气服务业' },
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '7', text: '食品、酒类制造业' },
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '8', text: '其他行业-轻资产' },
    { s_field_name: '客户行业2', s_field: 'customrIndustryClass', value: '9', text: '其他行业-重资产' },
    //资本市场:上市公司、拟上市公司、上市企业母/子公司、非上市企业
    { s_field_name: '资本市场', s_field: 'CAPITAL_MARKET', value: '1', text: '上市企业' },
    { s_field_name: '资本市场', s_field: 'CAPITAL_MARKET', value: '2', text: '拟上市企业' },
    { s_field_name: '资本市场', s_field: 'CAPITAL_MARKET', value: '3', text: '上市企业母/子公司' },
    { s_field_name: '资本市场', s_field: 'CAPITAL_MARKET', value: '4', text: '其他非上市企业' },
    //招商引资类型
    { s_field_name: '招商引资类型', s_field: 'INVESTMENT_TYPE', value: '1', text: '总行名单内招引客户' },
    { s_field_name: '招商引资类型', s_field: 'INVESTMENT_TYPE', value: '2', text: '已上报总行纳入招引名单管理客户' },
    { s_field_name: '招商引资类型', s_field: 'INVESTMENT_TYPE', value: '3', text: '拟报总行招引客户' },
    { s_field_name: '招商引资类型', s_field: 'INVESTMENT_TYPE', value: '4', text: '招商引资渠道建设类拜访' },
    { s_field_name: '招商引资类型', s_field: 'INVESTMENT_TYPE', value: '5', text: '非招商引资客户' },
    //营销方向
    { s_field_name: '营销方向', s_field: 'MARKET_DIRECTION', value: '1', text: '资产业务' },
    { s_field_name: '营销方向', s_field: 'MARKET_DIRECTION', value: '2', text: '负债业务' },
    { s_field_name: '营销方向', s_field: 'MARKET_DIRECTION', value: '3', text: '营销信息获取' },
    { s_field_name: '营销方向', s_field: 'MARKET_DIRECTION', value: '4', text: '其他' },
    //拜访目的
    { s_field_name: '拜访目的', s_field: 'VISIT_PURPOSE', value: '1', text: '初次拜访' },
    { s_field_name: '拜访目的', s_field: 'VISIT_PURPOSE', value: '2', text: '达成合作意向' },
    { s_field_name: '拜访目的', s_field: 'VISIT_PURPOSE', value: '3', text: '确定授信方案' },
    { s_field_name: '拜访目的', s_field: 'VISIT_PURPOSE', value: '4', text: '存量客户维护' },
    //拜访情况分类
    { s_field_name: '拜访情况分类', s_field: 'visitsClass', value: '1', text: '还需继续营销跟进' },
    { s_field_name: '拜访情况分类', s_field: 'visitsClass', value: '2', text: '拟上报授信审批' },
    { s_field_name: '拜访情况分类', s_field: 'visitsClass', value: '3', text: '已报授信审批' },
    { s_field_name: '拜访情况分类', s_field: 'visitsClass', value: '4', text: '不准备继续跟进' },
    //参与领导分类
    { s_field_name: '参与领导分类', s_field: 'PARTICIPATELEADER_TYPE', value: '1', text: '分支行行长' },
    { s_field_name: '参与领导分类', s_field: 'PARTICIPATELEADER_TYPE', value: '2', text: '分支行分管行长' },
    //招商企业类型
    { s_field_name: '招商企业类型', s_field: 'ENTERPRISES_TYPE', value: '1', text: '总行名单内客户' },
    { s_field_name: '招商企业类型', s_field: 'ENTERPRISES_TYPE', value: '2', text: '已上报总行纳入招引名单管理客户' },
    { s_field_name: '招商企业类型', s_field: 'ENTERPRISES_TYPE', value: '3', text: '拟报总行招引客户' },
    //营销目标
    { s_field_name: '营销目标', s_field: 'MARKETTARGET', value: '1', text: '负债业务' },
    { s_field_name: '营销目标', s_field: 'MARKETTARGET', value: '2', text: '资产业务' },
    { s_field_name: '营销目标', s_field: 'MARKETTARGET', value: '3', text: '信息摸排' },
    { s_field_name: '营销目标', s_field: 'MARKETTARGET', value: '4', text: '其他' },
    //招引项目当前进展
    { s_field_name: '招引项目当前进展', s_field: 'INVITPROJECT_PROGESS', value: '1', text: '项目洽谈阶段' },
    { s_field_name: '招引项目当前进展', s_field: 'INVITPROJECT_PROGESS', value: '2', text: '初步达成投资意向' },
    { s_field_name: '招引项目当前进展', s_field: 'INVITPROJECT_PROGESS', value: '3', text: '签订投资意向书' },
    { s_field_name: '招引项目当前进展', s_field: 'INVITPROJECT_PROGESS', value: '4', text: '项目规划' },
    { s_field_name: '招引项目当前进展', s_field: 'INVITPROJECT_PROGESS', value: '5', text: '项目签约' },
    { s_field_name: '招引项目当前进展', s_field: 'INVITPROJECT_PROGESS', value: '6', text: '项目公司登记' },
    { s_field_name: '招引项目当前进展', s_field: 'INVITPROJECT_PROGESS', value: '7', text: '项目建设' },
    { s_field_name: '招引项目当前进展', s_field: 'INVITPROJECT_PROGESS', value: '8', text: '项目运营' },
    //营销进展
    //1-前期营销、2-初步达成合作意向、3-资料收集中、4-分支行权限内已审批、5-已报总行授信审批、6-完成授信审批、7-已提用
    { s_field_name: '营销进展', s_field: 'MARKET_PROGESS', value: '1', text: '前期营销' },
    { s_field_name: '营销进展', s_field: 'MARKET_PROGESS', value: '2', text: '初步达成合作意向' },
    { s_field_name: '营销进展', s_field: 'MARKET_PROGESS', value: '3', text: '资料收集中' },
    { s_field_name: '营销进展', s_field: 'MARKET_PROGESS', value: '4', text: '分支行权限内已审批' },
    { s_field_name: '营销进展', s_field: 'MARKET_PROGESS', value: '5', text: '已报总行授信审批' },
    { s_field_name: '营销进展', s_field: 'MARKET_PROGESS', value: '6', text: '完成授信审批' },
    { s_field_name: '营销进展', s_field: 'MARKET_PROGESS', value: '7', text: '已提用' },
    //开户类型
    // 基本户、专户、一般户、其他类型账户、尚未开户
    { s_field_name: '开户类型', s_field: 'OPENACCOUNT_TYPE', value: '1', text: '基本户' },
    { s_field_name: '开户类型', s_field: 'OPENACCOUNT_TYPE', value: '2', text: '专户' },
    { s_field_name: '开户类型', s_field: 'OPENACCOUNT_TYPE', value: '3', text: '一般户' },
    { s_field_name: '开户类型', s_field: 'OPENACCOUNT_TYPE', value: '4', text: '其他类型账户' },
    { s_field_name: '开户类型', s_field: 'OPENACCOUNT_TYPE', value: '5', text: '尚未开户' },
    //对公流程查询
    //业务类型
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '110', text: '客户托管' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '111', text: '客户入网申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '112', text: '授信方案申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '113', text: '授信方案变更（重审）申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '120', text: '客户移交' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '121', text: '客户重大信息修改' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '130', text: '客户共享' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '131', text: '客户合并' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '140', text: '担保公司合作申请/变更/重审' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '141', text: '担保公司协议冻结' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '142', text: '担保公司协议解冻' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '143', text: '担保公司评级授信' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '144', text: '分离式保函协议冻结/解冻' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '145', text: '分离式保函协议变更/重审' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '150', text: '问题客户认定' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '151', text: '问题客户注销' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '210', text: '贷款申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '230', text: '贷款展期申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '231', text: '贷款利率预约调整申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '232', text: '出具远期受让承诺转化' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '233', text: '出具远期受让承诺注销' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '234', text: '非债申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '235', text: '非债期限调整申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '236', text: '非债合同' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '237', text: '非债出账' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '238', text: '非债还款' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '239', text: '非债提前还款' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '240', text: '非债期限调整合同' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '241', text: '非债期限调整出账' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '245', text: '国内保理申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '250', text: '保函申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '251', text: '银承申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '252', text: '分离式保函申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '253', text: '分离式保函合作申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '260', text: '贴现申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '261', text: '转贴现买入申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '262', text: '转贴现卖出申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '263', text: '委托代理贴现' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '270', text: '资产转让申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '271', text: '贸易融资申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '272', text: '国内信用证开证申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '273', text: '国内信用证代付申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '274', text: '国内信用证注销' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '275', text: '贸易融资展期申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '276', text: '贸易融资展期协议签订' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '277', text: '贸易融资展期出账申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '278', text: '进口信用证增额' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '280', text: '最高额担保合同申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '281', text: '最高额担保合同签订' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '282', text: '最高额担保合同变更' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '283', text: '国内信用证出账申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '284', text: '合同签订及出账' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '285', text: '抵质押品出入库' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '286', text: '保函核销' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '287', text: '还款账号变更' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '288', text: '最高额担保合同重签' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '321', text: '授信额度冻结解冻' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '330', text: '信用评级申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '350', text: '循环额度申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '351', text: '循环授信协议签订' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '352', text: '授信额度申请变更' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '353', text: '循环额度注销' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '360', text: '特色额度申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '370', text: '非专项风险限额申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '371', text: '非专项风险限额变更' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '372', text: '非专项风险限额冻结' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '373', text: '非专项风险限额解冻' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '410', text: '协议/合同流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '430', text: '出账流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '440', text: '风险分类流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '450', text: '提前还款' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '451', text: '押品价值重估' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '460', text: '减值流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '490', text: '担保品入库' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '491', text: '担保品出库' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '510', text: '担保变更' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '610', text: '不良资产认定' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '680', text: '资产保全流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '761', text: '票据池合作申请流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '762', text: '票据池质押担保合同申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '763', text: '票据池合作协议流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '764', text: '票据池质押担保合同签订' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '800', text: '保贴额度申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '801', text: '保贴额度变更申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '802', text: '保贴额度重审申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '803', text: '保贴额度续签申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '810', text: '保贴额度流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '821', text: '商票贴现出账流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '831', text: '商票备款申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '832', text: '贷后检查' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '833', text: '红色预警检查' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '834', text: '预警信号解除' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '835', text: '频率变更' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '840', text: '定期检查注销' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '900', text: '其他流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '901', text: '企业信用债买入申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '902', text: '企业信用债卖出申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '903', text: '企业信用债业务申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '904', text: '授信额度申请重审' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '910', text: '担保公司合作申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '911', text: '担保公司合作变更' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '912', text: '担保公司合作重审' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '920', text: '同业客户评级授信申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '921', text: '同业客户授信申请' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '922', text: '还款方式变更' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '966', text: '押品权证变更流程' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '977', text: '企业债主体授信-分支行' },
    { s_field_name: '流程业务类型', s_field: 'PROCESS_TYPE', value: '978', text: '企业债主体授信-资金部' },
    /*****************************对公营销* 开始 *********************************************/



    /*****************************线上金融产品 *********************************************/
    { s_field_name: '担保方式', s_field: 'LOAN_TYPE', value: '01', text: '抵押' },
    { s_field_name: '担保方式', s_field: 'LOAN_TYPE', value: '02', text: '质押' },
    { s_field_name: '担保方式', s_field: 'LOAN_TYPE', value: '03', text: '保证' },
    { s_field_name: '担保方式', s_field: 'LOAN_TYPE', value: '04', text: '信用' },

    { s_field_name: '贷款种类', s_field: 'PROD_TYPE', value: '0', text: '消费贷' },
    { s_field_name: '贷款种类', s_field: 'PROD_TYPE', value: '1', text: '购房贷' },


  ]);

  /**
   * @Description 从服务器查询字典保存至本地
   * @Author ZPFly
   * @Date 2021/10/12
   */
  init() {
    //TODO 需要通过接口先进行查询然后保存。
    localStorage.setItem("dictData", JSON.stringify(this.dictData));
    console.log("dicDataInit")
    // this.queryDictList().then((data: any) => {
    //   const dictData: any = {};
    //   data.forEach((item: any) => {
    //     if (!dictData[item.dictField]) dictData[item.dictField] = {};
    //     dictData[item.dictField][item.sKey] = item.sValue;
    //   });
    //   localStorage.setItem("dictData", JSON.stringify(dictData));
    // });
  }
  /**
   * @Description 查询数据字典列表
   * @Author ZPFly
   * @Date 2021/10/12
   */
  queryDictList() {
    const query = { updateTime: new Date() };
    return apiService.general(sysDictInfoApi.searchAll, query, {}).then((response: RestfulResponse) => {
      if (response.code == Code.SUCCESS.code) {
        return response.data;
      }
    });
  }
  /**
   * @Description 根据field获取字典
   * @Author ZPFly
   * @Date 2021/10/12
   */
  getOptions(dictField: string) {
    let dictData: any = localStorage.getItem("dictData");
    const options: any = [];
    dictData = dictData ? JSON.parse(dictData) : {};
    dictData.forEach((item: any) => {
      if (item.s_field == dictField){
        options.push(item);
      }
    });
    return options;
  }

  /**
   * @Description 根据value, dictField获取字典中文描述
   * @Author ZPFly
   * @Date 2021/10/12
   */
  getText(val: any, s_field: any) {
    if (!s_field) return val;
    if (!val) return val;
    let dicOptions = {},
      serviceDictionary = JSON.parse(localStorage.getItem("dictData") || '[]');
    if (typeof serviceDictionary != 'object') {
      serviceDictionary = JSON.parse(serviceDictionary);
    }
    dicOptions[s_field] = serviceDictionary.filter((item: any) => item.s_field === s_field);
    let text = dicOptions[s_field].find((item: any) => item.value === val);
    if (!text) {
      return val;
    }
    return text.text;
  }

  /**
   * @description 数组转树形结构
   * @Author ZPFly
   * @param {Object} datas [{dictField, sKey, sValue, fSKey }]
   */
  arrayToTree(datas: any[]) {
    const data = JSON.parse(JSON.stringify(datas));
    const result: any[] = [];
    if (!Array.isArray(data)) {
      return result;
    }
    const map: any = {};
    data.forEach((item) => {
      map[item.sKey] = item;
    });
    data.forEach((item) => {
      const parent = map[item.fSKey];
      if (parent) {
        (parent.children || (parent.children = [])).push(item);
      } else {
        result.push(item);
      }
    });
    return result;
  }
}
const dictData = new DictService();
export default dictData;
